# wikitude_studio_api_client

WikitudeStudioAPIClient - the Ruby gem for the Wikitude Studio API

The Wikitude Studio API is a RESTful API which is used to
* organize and manipulate projects and its targets
* create wtc/wto files which can be used to create trackers in the Wikitude SDK with the JavaScript API
* generate/publish a cloud archive to the cloud recognition service (image targets only)

Download API clients:
* [`OpenAPI 3.0`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-openapi.zip)
* [`JavaScript`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-javascript.zip)
* [`Python`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-python.zip)
* [`PHP`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-php.zip)
* [`TypeScript (NodeJS)`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-typescript-node.zip)
* [`Java`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-java.zip)
* [`Ruby`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-ruby.zip)
* [`C# .NET Core`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-csharp-netcore.zip)

This technical reference formally explains various API endpoints.
Visit the [`Studio API documentation`](https://www.wikitude.com/external/doc/documentation/studio/) for a more general description.


This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 3.0.0
- Package version: 3.0.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build wikitude_studio_api_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./wikitude_studio_api_client-3.0.0.gem
```

(for development, run `gem install --dev ./wikitude_studio_api_client-3.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'wikitude_studio_api_client', '~> 3.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'wikitude_studio_api_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::AccountApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.

begin
  #Get account information
  result = api_instance.get_account(x_version, x_token)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Exception when calling AccountApi->get_account: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api-eu.wikitude.com/cloudrecognition*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*WikitudeStudioAPIClient::AccountApi* | [**get_account**](docs/AccountApi.md#get_account) | **GET** /account | Get account information
*WikitudeStudioAPIClient::HeatmapApi* | [**generate_heatmap**](docs/HeatmapApi.md#generate_heatmap) | **POST** /heatmap | Generate Heatmap
*WikitudeStudioAPIClient::HeatmapApi* | [**get_heatmap_status**](docs/HeatmapApi.md#get_heatmap_status) | **GET** /heatmap/{generationId} | Status - Generate Heatmap
*WikitudeStudioAPIClient::ImageTargetApi* | [**create_image_targets**](docs/ImageTargetApi.md#create_image_targets) | **POST** /targetCollection/{tcId}/targets | Create Image Targets
*WikitudeStudioAPIClient::ImageTargetApi* | [**delete_image_target**](docs/ImageTargetApi.md#delete_image_target) | **DELETE** /targetCollection/{tcId}/target/{targetId} | Delete Image Target
*WikitudeStudioAPIClient::ImageTargetApi* | [**get_image_target**](docs/ImageTargetApi.md#get_image_target) | **GET** /targetCollection/{tcId}/target/{targetId} | Get Image Target
*WikitudeStudioAPIClient::ImageTargetApi* | [**get_image_target_status**](docs/ImageTargetApi.md#get_image_target_status) | **GET** /targetCollection/{tcId}/generation/targets/{generationId} | Status - Image Targets Creation
*WikitudeStudioAPIClient::ImageTargetApi* | [**get_image_targets**](docs/ImageTargetApi.md#get_image_targets) | **GET** /targetCollection/{tcId}/target | Get Image Targets
*WikitudeStudioAPIClient::ImageTargetApi* | [**update_image_target**](docs/ImageTargetApi.md#update_image_target) | **POST** /targetCollection/{tcId}/target/{targetId} | Update Image Target
*WikitudeStudioAPIClient::ImageTargetCollectionApi* | [**create_image_target_collection**](docs/ImageTargetCollectionApi.md#create_image_target_collection) | **POST** /targetCollection | Create Image Target Collection
*WikitudeStudioAPIClient::ImageTargetCollectionApi* | [**delete_image_target_collection**](docs/ImageTargetCollectionApi.md#delete_image_target_collection) | **DELETE** /targetCollection/{tcId} | Delete Image Target Collection
*WikitudeStudioAPIClient::ImageTargetCollectionApi* | [**generate_cloud_archive**](docs/ImageTargetCollectionApi.md#generate_cloud_archive) | **POST** /targetCollection/{tcId}/generation/cloudarchive | Generate Cloud Archive
*WikitudeStudioAPIClient::ImageTargetCollectionApi* | [**generate_wtc**](docs/ImageTargetCollectionApi.md#generate_wtc) | **POST** /targetCollection/{tcId}/generation/wtc | Generate WTC
*WikitudeStudioAPIClient::ImageTargetCollectionApi* | [**get_cloud_archive_status**](docs/ImageTargetCollectionApi.md#get_cloud_archive_status) | **GET** /targetCollection/{tcId}/generation/cloudarchive/{generationId} | Status - Generate Cloud Archive
*WikitudeStudioAPIClient::ImageTargetCollectionApi* | [**get_image_target_collection**](docs/ImageTargetCollectionApi.md#get_image_target_collection) | **GET** /targetCollection/{tcId} | Get Image Target Collection
*WikitudeStudioAPIClient::ImageTargetCollectionApi* | [**get_image_target_collections**](docs/ImageTargetCollectionApi.md#get_image_target_collections) | **GET** /targetCollection | Get all Image Target Collections
*WikitudeStudioAPIClient::ImageTargetCollectionApi* | [**get_similarity_check_status**](docs/ImageTargetCollectionApi.md#get_similarity_check_status) | **GET** /targetCollection/{tcId}/similarity/{generationId} | Status - Similarity Check
*WikitudeStudioAPIClient::ImageTargetCollectionApi* | [**get_wtc_status**](docs/ImageTargetCollectionApi.md#get_wtc_status) | **GET** /targetCollection/{tcId}/generation/wtc/{generationId} | Status - Generate WTC
*WikitudeStudioAPIClient::ImageTargetCollectionApi* | [**similarity_check**](docs/ImageTargetCollectionApi.md#similarity_check) | **POST** /targetCollection/{tcId}/similarity | Similarity Check
*WikitudeStudioAPIClient::ImageTargetCollectionApi* | [**update_image_target_collection**](docs/ImageTargetCollectionApi.md#update_image_target_collection) | **POST** /targetCollection/{tcId} | Update Image Target Collection
*WikitudeStudioAPIClient::ObjectTargetApi* | [**create_object_target_from_images**](docs/ObjectTargetApi.md#create_object_target_from_images) | **POST** /objectTargetCollection/{tcId}/target/images | Create Object Target from Images
*WikitudeStudioAPIClient::ObjectTargetApi* | [**create_object_target_from_wto**](docs/ObjectTargetApi.md#create_object_target_from_wto) | **POST** /objectTargetCollection/{tcId}/target/wto | Create Object Target from WTO
*WikitudeStudioAPIClient::ObjectTargetApi* | [**delete_object_target**](docs/ObjectTargetApi.md#delete_object_target) | **DELETE** /objectTargetCollection/{tcId}/target/{targetId} | Delete Object Target
*WikitudeStudioAPIClient::ObjectTargetApi* | [**extend_object_target**](docs/ObjectTargetApi.md#extend_object_target) | **PUT** /objectTargetCollection/{tcId}/target/{targetId} | Extend Object Target
*WikitudeStudioAPIClient::ObjectTargetApi* | [**get_object_target**](docs/ObjectTargetApi.md#get_object_target) | **GET** /objectTargetCollection/{tcId}/target/{targetId} | Get Object Target
*WikitudeStudioAPIClient::ObjectTargetApi* | [**get_object_target_status**](docs/ObjectTargetApi.md#get_object_target_status) | **GET** /objectTargetCollection/{tcId}/generation/targets/{generationId} | Status - Object Target Generation Information
*WikitudeStudioAPIClient::ObjectTargetApi* | [**get_object_targets**](docs/ObjectTargetApi.md#get_object_targets) | **GET** /objectTargetCollection/{tcId}/target | Get Object Targets
*WikitudeStudioAPIClient::ObjectTargetApi* | [**rename_object_target**](docs/ObjectTargetApi.md#rename_object_target) | **PUT** /objectTargetCollection/{tcId}/target/{targetId}/name | Rename Object Target
*WikitudeStudioAPIClient::ObjectTargetCollectionApi* | [**create_object_target_collection**](docs/ObjectTargetCollectionApi.md#create_object_target_collection) | **POST** /objectTargetCollection | Create Object Target Collection
*WikitudeStudioAPIClient::ObjectTargetCollectionApi* | [**delete_object_target_collection**](docs/ObjectTargetCollectionApi.md#delete_object_target_collection) | **DELETE** /objectTargetCollection/{tcId} | Delete Object Target Collection
*WikitudeStudioAPIClient::ObjectTargetCollectionApi* | [**generate_wto**](docs/ObjectTargetCollectionApi.md#generate_wto) | **POST** /objectTargetCollection/{tcId}/generation/wto | Generate WTO
*WikitudeStudioAPIClient::ObjectTargetCollectionApi* | [**get_object_target_collection**](docs/ObjectTargetCollectionApi.md#get_object_target_collection) | **GET** /objectTargetCollection/{tcId} | Get Object Target Collection
*WikitudeStudioAPIClient::ObjectTargetCollectionApi* | [**get_object_target_collection_status**](docs/ObjectTargetCollectionApi.md#get_object_target_collection_status) | **GET** /objectTargetCollection/{tcId}/jobs | Status - Get Object Target Collection jobs
*WikitudeStudioAPIClient::ObjectTargetCollectionApi* | [**get_object_target_collections**](docs/ObjectTargetCollectionApi.md#get_object_target_collections) | **GET** /objectTargetCollection | Get all Object Target Collections
*WikitudeStudioAPIClient::ObjectTargetCollectionApi* | [**get_wto_status**](docs/ObjectTargetCollectionApi.md#get_wto_status) | **GET** /objectTargetCollection/{tcId}/generation/wto/{generationId} | Status - Generate WTO
*WikitudeStudioAPIClient::ObjectTargetCollectionApi* | [**update_object_target_collection**](docs/ObjectTargetCollectionApi.md#update_object_target_collection) | **PUT** /objectTargetCollection/{tcId} | Update Object Target Collection
*WikitudeStudioAPIClient::ProjectApi* | [**get_projects**](docs/ProjectApi.md#get_projects) | **GET** /projects | Get all projects


## Documentation for Models

 - [WikitudeStudioAPIClient::CloudArchiveGenerationResponse](docs/CloudArchiveGenerationResponse.md)
 - [WikitudeStudioAPIClient::CloudArchiveGenerationResponseInputParams](docs/CloudArchiveGenerationResponseInputParams.md)
 - [WikitudeStudioAPIClient::CreateImageTargetCollectionBody](docs/CreateImageTargetCollectionBody.md)
 - [WikitudeStudioAPIClient::CreateImageTargetCollectionBodyCloudArchive](docs/CreateImageTargetCollectionBodyCloudArchive.md)
 - [WikitudeStudioAPIClient::CreateImageTargetsBody](docs/CreateImageTargetsBody.md)
 - [WikitudeStudioAPIClient::CreateImageTargetsResponse](docs/CreateImageTargetsResponse.md)
 - [WikitudeStudioAPIClient::CreateImageTargetsResponseInputParams](docs/CreateImageTargetsResponseInputParams.md)
 - [WikitudeStudioAPIClient::CreateImageTargetsResponseInputParamsTargets](docs/CreateImageTargetsResponseInputParamsTargets.md)
 - [WikitudeStudioAPIClient::CreateObjectTargetCollectionBody](docs/CreateObjectTargetCollectionBody.md)
 - [WikitudeStudioAPIClient::CreateObjectTargetImagesBody](docs/CreateObjectTargetImagesBody.md)
 - [WikitudeStudioAPIClient::CreateObjectTargetImagesBodyResource](docs/CreateObjectTargetImagesBodyResource.md)
 - [WikitudeStudioAPIClient::CreateObjectTargetWTOBody](docs/CreateObjectTargetWTOBody.md)
 - [WikitudeStudioAPIClient::CreateObjectTargetWTOBodyResource](docs/CreateObjectTargetWTOBodyResource.md)
 - [WikitudeStudioAPIClient::ExtendObjectTargetBody](docs/ExtendObjectTargetBody.md)
 - [WikitudeStudioAPIClient::GenerateHeatmapBody](docs/GenerateHeatmapBody.md)
 - [WikitudeStudioAPIClient::GenerateHeatmapResponse](docs/GenerateHeatmapResponse.md)
 - [WikitudeStudioAPIClient::GenerateHeatmapResponseInputParams](docs/GenerateHeatmapResponseInputParams.md)
 - [WikitudeStudioAPIClient::GenerateHeatmapStatusResponse](docs/GenerateHeatmapStatusResponse.md)
 - [WikitudeStudioAPIClient::GenerateHeatmapStatusResponsePayload](docs/GenerateHeatmapStatusResponsePayload.md)
 - [WikitudeStudioAPIClient::GenerateWTCBody](docs/GenerateWTCBody.md)
 - [WikitudeStudioAPIClient::GenerateWTCStatusResponse](docs/GenerateWTCStatusResponse.md)
 - [WikitudeStudioAPIClient::GenerateWTOBody](docs/GenerateWTOBody.md)
 - [WikitudeStudioAPIClient::GetAccountInfoResponse](docs/GetAccountInfoResponse.md)
 - [WikitudeStudioAPIClient::GetAccountInfoResponseStorage](docs/GetAccountInfoResponseStorage.md)
 - [WikitudeStudioAPIClient::ImageTargetCollectionResponse](docs/ImageTargetCollectionResponse.md)
 - [WikitudeStudioAPIClient::ImageTargetCollectionResponseCloudArchive](docs/ImageTargetCollectionResponseCloudArchive.md)
 - [WikitudeStudioAPIClient::ImageTargetCollectionResponseWtc](docs/ImageTargetCollectionResponseWtc.md)
 - [WikitudeStudioAPIClient::ImageTargetResponse](docs/ImageTargetResponse.md)
 - [WikitudeStudioAPIClient::ObjectTargetCollectionJobResponse](docs/ObjectTargetCollectionJobResponse.md)
 - [WikitudeStudioAPIClient::ObjectTargetCollectionResponse](docs/ObjectTargetCollectionResponse.md)
 - [WikitudeStudioAPIClient::ObjectTargetCollectionResponseWto](docs/ObjectTargetCollectionResponseWto.md)
 - [WikitudeStudioAPIClient::ObjectTargetJobResponse](docs/ObjectTargetJobResponse.md)
 - [WikitudeStudioAPIClient::ObjectTargetResponse](docs/ObjectTargetResponse.md)
 - [WikitudeStudioAPIClient::ObjectTargetResponseResource](docs/ObjectTargetResponseResource.md)
 - [WikitudeStudioAPIClient::ObjectTargetResponseWtoFile](docs/ObjectTargetResponseWtoFile.md)
 - [WikitudeStudioAPIClient::RenameObjectTargetBody](docs/RenameObjectTargetBody.md)
 - [WikitudeStudioAPIClient::SimilarityCheckBody](docs/SimilarityCheckBody.md)
 - [WikitudeStudioAPIClient::SimilarityCheckBodyImages](docs/SimilarityCheckBodyImages.md)
 - [WikitudeStudioAPIClient::SimilarityCheckResponse](docs/SimilarityCheckResponse.md)
 - [WikitudeStudioAPIClient::SimilarityCheckResponseInputParams](docs/SimilarityCheckResponseInputParams.md)
 - [WikitudeStudioAPIClient::SimilarityCheckResponseInputParamsImages](docs/SimilarityCheckResponseInputParamsImages.md)
 - [WikitudeStudioAPIClient::SimilarityCheckStatusResponse](docs/SimilarityCheckStatusResponse.md)
 - [WikitudeStudioAPIClient::SimilarityCheckStatusResponseCandidates](docs/SimilarityCheckStatusResponseCandidates.md)
 - [WikitudeStudioAPIClient::SimilarityCheckStatusResponseInputParams](docs/SimilarityCheckStatusResponseInputParams.md)
 - [WikitudeStudioAPIClient::SimilarityCheckStatusResponsePayload](docs/SimilarityCheckStatusResponsePayload.md)
 - [WikitudeStudioAPIClient::UpdateImageTargetBody](docs/UpdateImageTargetBody.md)
 - [WikitudeStudioAPIClient::UpdateImageTargetCollectionBody](docs/UpdateImageTargetCollectionBody.md)
 - [WikitudeStudioAPIClient::UpdateObjectTargetCollectionBody](docs/UpdateObjectTargetCollectionBody.md)


## Documentation for Authorization

 All endpoints do not require authorization.

