# WikitudeStudioAPIClient::HeatmapApi

All URIs are relative to *https://api-eu.wikitude.com/cloudrecognition*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**generate_heatmap**](HeatmapApi.md#generate_heatmap) | **POST** /heatmap | Generate Heatmap |
| [**get_heatmap_status**](HeatmapApi.md#get_heatmap_status) | **GET** /heatmap/{generationId} | Status - Generate Heatmap |


## generate_heatmap

> <GenerateHeatmapResponse> generate_heatmap(x_version, x_token, content_type, generate_heatmap_body)

Generate Heatmap

Generates a greyscale image out of the input image, where areas with recognition and tracking relevance are highlighted in color. This way one can better understand the rating of an image and see which areas have the highest importance for 2D recognition and tracking. Note that only JPG and non-transparent PNG files are accepted and the generated heatmap image is stored on a temporary folder which is deleted after 24 hours. Store the image on your own server in case you plan to use it in your user interface. 

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::HeatmapApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
content_type = 'content_type_example' # String | The Content Type of the body. Must be set to application/json.
generate_heatmap_body = WikitudeStudioAPIClient::GenerateHeatmapBody.new # GenerateHeatmapBody | 

begin
  # Generate Heatmap
  result = api_instance.generate_heatmap(x_version, x_token, content_type, generate_heatmap_body)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling HeatmapApi->generate_heatmap: #{e}"
end
```

#### Using the generate_heatmap_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<GenerateHeatmapResponse>, Integer, Hash)> generate_heatmap_with_http_info(x_version, x_token, content_type, generate_heatmap_body)

```ruby
begin
  # Generate Heatmap
  data, status_code, headers = api_instance.generate_heatmap_with_http_info(x_version, x_token, content_type, generate_heatmap_body)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <GenerateHeatmapResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling HeatmapApi->generate_heatmap_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **content_type** | **String** | The Content Type of the body. Must be set to application/json. |  |
| **generate_heatmap_body** | [**GenerateHeatmapBody**](GenerateHeatmapBody.md) |  |  |

### Return type

[**GenerateHeatmapResponse**](GenerateHeatmapResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## get_heatmap_status

> <GenerateHeatmapStatusResponse> get_heatmap_status(x_version, x_token, generation_id)

Status - Generate Heatmap

Retrieves information status about a particular scheduled heatmap creation.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::HeatmapApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
generation_id = 'generation_id_example' # String | Unique identifier of the asynchronous job created by a generation endpoint.

begin
  # Status - Generate Heatmap
  result = api_instance.get_heatmap_status(x_version, x_token, generation_id)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling HeatmapApi->get_heatmap_status: #{e}"
end
```

#### Using the get_heatmap_status_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<GenerateHeatmapStatusResponse>, Integer, Hash)> get_heatmap_status_with_http_info(x_version, x_token, generation_id)

```ruby
begin
  # Status - Generate Heatmap
  data, status_code, headers = api_instance.get_heatmap_status_with_http_info(x_version, x_token, generation_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <GenerateHeatmapStatusResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling HeatmapApi->get_heatmap_status_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **generation_id** | **String** | Unique identifier of the asynchronous job created by a generation endpoint. |  |

### Return type

[**GenerateHeatmapStatusResponse**](GenerateHeatmapStatusResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

