# WikitudeStudioAPIClient::ImageTargetApi

All URIs are relative to *https://api-eu.wikitude.com/cloudrecognition*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**create_image_targets**](ImageTargetApi.md#create_image_targets) | **POST** /targetCollection/{tcId}/targets | Create Image Targets |
| [**delete_image_target**](ImageTargetApi.md#delete_image_target) | **DELETE** /targetCollection/{tcId}/target/{targetId} | Delete Image Target |
| [**get_image_target**](ImageTargetApi.md#get_image_target) | **GET** /targetCollection/{tcId}/target/{targetId} | Get Image Target |
| [**get_image_target_status**](ImageTargetApi.md#get_image_target_status) | **GET** /targetCollection/{tcId}/generation/targets/{generationId} | Status - Image Targets Creation |
| [**get_image_targets**](ImageTargetApi.md#get_image_targets) | **GET** /targetCollection/{tcId}/target | Get Image Targets |
| [**update_image_target**](ImageTargetApi.md#update_image_target) | **POST** /targetCollection/{tcId}/target/{targetId} | Update Image Target |


## create_image_targets

> <CreateImageTargetsResponse> create_image_targets(x_version, x_token, content_type, tc_id, opts)

Create Image Targets

Create a set of up to 10 new Targets in a Target Collection in your account. The task to create the listed Targets is scheduled. The response body contains the initial job status. \"Location\"-header is the url to the GET endpoint that returns current job status information. It is recommended to query this endpoint after \"estimatedLatency\" milliseconds, and poll it afterwards every 10 seconds in case job status is still not \"COMPLETED\". Once job status is \"COMPLETED\" each item holds a \"target\" attribute of the created target or an \"error\" attribute. 

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
content_type = 'content_type_example' # String | The Content Type of the body. Must be set to application/json.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.
opts = {
  create_image_targets_body: [WikitudeStudioAPIClient::CreateImageTargetsBody.new] # Array<CreateImageTargetsBody> | 
}

begin
  # Create Image Targets
  result = api_instance.create_image_targets(x_version, x_token, content_type, tc_id, opts)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetApi->create_image_targets: #{e}"
end
```

#### Using the create_image_targets_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CreateImageTargetsResponse>, Integer, Hash)> create_image_targets_with_http_info(x_version, x_token, content_type, tc_id, opts)

```ruby
begin
  # Create Image Targets
  data, status_code, headers = api_instance.create_image_targets_with_http_info(x_version, x_token, content_type, tc_id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CreateImageTargetsResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetApi->create_image_targets_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **content_type** | **String** | The Content Type of the body. Must be set to application/json. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |
| **create_image_targets_body** | [**Array&lt;CreateImageTargetsBody&gt;**](CreateImageTargetsBody.md) |  | [optional] |

### Return type

[**CreateImageTargetsResponse**](CreateImageTargetsResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## delete_image_target

> delete_image_target(x_version, x_token, tc_id, target_id)

Delete Image Target

Delete a particular Target from your account.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.
target_id = 'target_id_example' # String | Unique identifier of the Image Target.

begin
  # Delete Image Target
  api_instance.delete_image_target(x_version, x_token, tc_id, target_id)
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetApi->delete_image_target: #{e}"
end
```

#### Using the delete_image_target_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_image_target_with_http_info(x_version, x_token, tc_id, target_id)

```ruby
begin
  # Delete Image Target
  data, status_code, headers = api_instance.delete_image_target_with_http_info(x_version, x_token, tc_id, target_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetApi->delete_image_target_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |
| **target_id** | **String** | Unique identifier of the Image Target. |  |

### Return type

nil (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## get_image_target

> <ImageTargetResponse> get_image_target(x_version, x_token, tc_id, target_id)

Get Image Target

Request a particular Image Target in a particular Target Collection.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.
target_id = 'target_id_example' # String | Unique identifier of the Image Target.

begin
  # Get Image Target
  result = api_instance.get_image_target(x_version, x_token, tc_id, target_id)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetApi->get_image_target: #{e}"
end
```

#### Using the get_image_target_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ImageTargetResponse>, Integer, Hash)> get_image_target_with_http_info(x_version, x_token, tc_id, target_id)

```ruby
begin
  # Get Image Target
  data, status_code, headers = api_instance.get_image_target_with_http_info(x_version, x_token, tc_id, target_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ImageTargetResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetApi->get_image_target_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |
| **target_id** | **String** | Unique identifier of the Image Target. |  |

### Return type

[**ImageTargetResponse**](ImageTargetResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_image_target_status

> <CreateImageTargetsResponse> get_image_target_status(x_version, x_token, tc_id, generation_id)

Status - Image Targets Creation

Retrieves information status about a particular scheduled targets creation.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.
generation_id = 'generation_id_example' # String | Unique identifier of the asynchronous job created by a generation endpoint.

begin
  # Status - Image Targets Creation
  result = api_instance.get_image_target_status(x_version, x_token, tc_id, generation_id)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetApi->get_image_target_status: #{e}"
end
```

#### Using the get_image_target_status_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CreateImageTargetsResponse>, Integer, Hash)> get_image_target_status_with_http_info(x_version, x_token, tc_id, generation_id)

```ruby
begin
  # Status - Image Targets Creation
  data, status_code, headers = api_instance.get_image_target_status_with_http_info(x_version, x_token, tc_id, generation_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CreateImageTargetsResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetApi->get_image_target_status_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |
| **generation_id** | **String** | Unique identifier of the asynchronous job created by a generation endpoint. |  |

### Return type

[**CreateImageTargetsResponse**](CreateImageTargetsResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_image_targets

> <Array<ImageTargetResponse>> get_image_targets(x_version, x_token, tc_id, opts)

Get Image Targets

Request all Image Targets in a Target Collection.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.
opts = {
  sortby: 'sortby_example', # String | Targets may be sorted by 'name', 'creDat', 'modDat', 'rating'. Default value: 'creDat'
  sortorder: 'sortorder_example', # String | Targets may be sorted ascending ('asc') or descending ('desc'). Default value: 'desc'
  skip: 8.14, # Float | Set 0 to start with first target, set e.g. to 2 to skip first 2 targets. Default value: 0
  limit: 8.14, # Float | Set to 0 for 'all targets' or use positive value to define max. amount of targets to return. Default value: 0
  s: 's_example', # String | The search string to look for in target names.
  add_has_augmentations: true # Boolean | Add the hasAugmentations property.
}

begin
  # Get Image Targets
  result = api_instance.get_image_targets(x_version, x_token, tc_id, opts)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetApi->get_image_targets: #{e}"
end
```

#### Using the get_image_targets_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<ImageTargetResponse>>, Integer, Hash)> get_image_targets_with_http_info(x_version, x_token, tc_id, opts)

```ruby
begin
  # Get Image Targets
  data, status_code, headers = api_instance.get_image_targets_with_http_info(x_version, x_token, tc_id, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<ImageTargetResponse>>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetApi->get_image_targets_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |
| **sortby** | **String** | Targets may be sorted by &#39;name&#39;, &#39;creDat&#39;, &#39;modDat&#39;, &#39;rating&#39;. Default value: &#39;creDat&#39; | [optional] |
| **sortorder** | **String** | Targets may be sorted ascending (&#39;asc&#39;) or descending (&#39;desc&#39;). Default value: &#39;desc&#39; | [optional] |
| **skip** | **Float** | Set 0 to start with first target, set e.g. to 2 to skip first 2 targets. Default value: 0 | [optional] |
| **limit** | **Float** | Set to 0 for &#39;all targets&#39; or use positive value to define max. amount of targets to return. Default value: 0 | [optional] |
| **s** | **String** | The search string to look for in target names. | [optional] |
| **add_has_augmentations** | **Boolean** | Add the hasAugmentations property. | [optional] |

### Return type

[**Array&lt;ImageTargetResponse&gt;**](ImageTargetResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update_image_target

> <ImageTargetResponse> update_image_target(x_version, x_token, content_type, tc_id, target_id, update_image_target_body)

Update Image Target

Updates properties of a particular Target in your account. Currently following properties are supported: physicalHeight, metadata. 

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
content_type = 'content_type_example' # String | The Content Type of the body. Must be set to application/json.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.
target_id = 'target_id_example' # String | Unique identifier of the Image Target.
update_image_target_body = WikitudeStudioAPIClient::UpdateImageTargetBody.new # UpdateImageTargetBody | 

begin
  # Update Image Target
  result = api_instance.update_image_target(x_version, x_token, content_type, tc_id, target_id, update_image_target_body)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetApi->update_image_target: #{e}"
end
```

#### Using the update_image_target_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ImageTargetResponse>, Integer, Hash)> update_image_target_with_http_info(x_version, x_token, content_type, tc_id, target_id, update_image_target_body)

```ruby
begin
  # Update Image Target
  data, status_code, headers = api_instance.update_image_target_with_http_info(x_version, x_token, content_type, tc_id, target_id, update_image_target_body)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ImageTargetResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetApi->update_image_target_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **content_type** | **String** | The Content Type of the body. Must be set to application/json. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |
| **target_id** | **String** | Unique identifier of the Image Target. |  |
| **update_image_target_body** | [**UpdateImageTargetBody**](UpdateImageTargetBody.md) |  |  |

### Return type

[**ImageTargetResponse**](ImageTargetResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

