# WikitudeStudioAPIClient::ImageTargetCollectionApi

All URIs are relative to *https://api-eu.wikitude.com/cloudrecognition*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**create_image_target_collection**](ImageTargetCollectionApi.md#create_image_target_collection) | **POST** /targetCollection | Create Image Target Collection |
| [**delete_image_target_collection**](ImageTargetCollectionApi.md#delete_image_target_collection) | **DELETE** /targetCollection/{tcId} | Delete Image Target Collection |
| [**generate_cloud_archive**](ImageTargetCollectionApi.md#generate_cloud_archive) | **POST** /targetCollection/{tcId}/generation/cloudarchive | Generate Cloud Archive |
| [**generate_wtc**](ImageTargetCollectionApi.md#generate_wtc) | **POST** /targetCollection/{tcId}/generation/wtc | Generate WTC |
| [**get_cloud_archive_status**](ImageTargetCollectionApi.md#get_cloud_archive_status) | **GET** /targetCollection/{tcId}/generation/cloudarchive/{generationId} | Status - Generate Cloud Archive |
| [**get_image_target_collection**](ImageTargetCollectionApi.md#get_image_target_collection) | **GET** /targetCollection/{tcId} | Get Image Target Collection |
| [**get_image_target_collections**](ImageTargetCollectionApi.md#get_image_target_collections) | **GET** /targetCollection | Get all Image Target Collections |
| [**get_similarity_check_status**](ImageTargetCollectionApi.md#get_similarity_check_status) | **GET** /targetCollection/{tcId}/similarity/{generationId} | Status - Similarity Check |
| [**get_wtc_status**](ImageTargetCollectionApi.md#get_wtc_status) | **GET** /targetCollection/{tcId}/generation/wtc/{generationId} | Status - Generate WTC |
| [**similarity_check**](ImageTargetCollectionApi.md#similarity_check) | **POST** /targetCollection/{tcId}/similarity | Similarity Check |
| [**update_image_target_collection**](ImageTargetCollectionApi.md#update_image_target_collection) | **POST** /targetCollection/{tcId} | Update Image Target Collection |


## create_image_target_collection

> <ImageTargetCollectionResponse> create_image_target_collection(x_version, x_token, content_type, create_image_target_collection_body)

Create Image Target Collection

Create a new target collection in your account.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetCollectionApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
content_type = 'content_type_example' # String | The Content Type of the body. Must be set to application/json.
create_image_target_collection_body = WikitudeStudioAPIClient::CreateImageTargetCollectionBody.new # CreateImageTargetCollectionBody | 

begin
  # Create Image Target Collection
  result = api_instance.create_image_target_collection(x_version, x_token, content_type, create_image_target_collection_body)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->create_image_target_collection: #{e}"
end
```

#### Using the create_image_target_collection_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ImageTargetCollectionResponse>, Integer, Hash)> create_image_target_collection_with_http_info(x_version, x_token, content_type, create_image_target_collection_body)

```ruby
begin
  # Create Image Target Collection
  data, status_code, headers = api_instance.create_image_target_collection_with_http_info(x_version, x_token, content_type, create_image_target_collection_body)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ImageTargetCollectionResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->create_image_target_collection_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **content_type** | **String** | The Content Type of the body. Must be set to application/json. |  |
| **create_image_target_collection_body** | [**CreateImageTargetCollectionBody**](CreateImageTargetCollectionBody.md) |  |  |

### Return type

[**ImageTargetCollectionResponse**](ImageTargetCollectionResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## delete_image_target_collection

> delete_image_target_collection(x_version, x_token, tc_id)

Delete Image Target Collection

Delete a particular target collection from your account.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetCollectionApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.

begin
  # Delete Image Target Collection
  api_instance.delete_image_target_collection(x_version, x_token, tc_id)
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->delete_image_target_collection: #{e}"
end
```

#### Using the delete_image_target_collection_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_image_target_collection_with_http_info(x_version, x_token, tc_id)

```ruby
begin
  # Delete Image Target Collection
  data, status_code, headers = api_instance.delete_image_target_collection_with_http_info(x_version, x_token, tc_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->delete_image_target_collection_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |

### Return type

nil (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## generate_cloud_archive

> <CloudArchiveGenerationResponse> generate_cloud_archive(x_version, x_token, tc_id)

Generate Cloud Archive

DEPRECATED - Generate a Cloud Archive from an existing Target Collection. The call is asynchronous and contains a path in the response header (Location) from which the status of the generation can be requested (see Status - Generate Cloud Archive). As of release 4.0.0 this endpoint will return error TARGET_COLLECTION_IS_UP_TO_DATE with status code 412, since the archive will be generated automatically in the background in the future. This endpoint is marked as \"deprecated\" since the behaviour will slightly change. However, this endpoint will still exist in version 3. 

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetCollectionApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.

begin
  # Generate Cloud Archive
  result = api_instance.generate_cloud_archive(x_version, x_token, tc_id)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->generate_cloud_archive: #{e}"
end
```

#### Using the generate_cloud_archive_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CloudArchiveGenerationResponse>, Integer, Hash)> generate_cloud_archive_with_http_info(x_version, x_token, tc_id)

```ruby
begin
  # Generate Cloud Archive
  data, status_code, headers = api_instance.generate_cloud_archive_with_http_info(x_version, x_token, tc_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CloudArchiveGenerationResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->generate_cloud_archive_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |

### Return type

[**CloudArchiveGenerationResponse**](CloudArchiveGenerationResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## generate_wtc

> <GenerateWTCStatusResponse> generate_wtc(x_version, x_token, content_type, tc_id, generate_wtc_body)

Generate WTC

Generates a WTC file out of an existing Target Collection with up to 1000 targets. The call is asynchronous and contains a path in the response header (Location) from which the status of the generation can be requested (see Status - Generate WTC). 

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetCollectionApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
content_type = 'content_type_example' # String | The Content Type of the body. Must be set to application/json.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.
generate_wtc_body = WikitudeStudioAPIClient::GenerateWTCBody.new # GenerateWTCBody | 

begin
  # Generate WTC
  result = api_instance.generate_wtc(x_version, x_token, content_type, tc_id, generate_wtc_body)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->generate_wtc: #{e}"
end
```

#### Using the generate_wtc_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<GenerateWTCStatusResponse>, Integer, Hash)> generate_wtc_with_http_info(x_version, x_token, content_type, tc_id, generate_wtc_body)

```ruby
begin
  # Generate WTC
  data, status_code, headers = api_instance.generate_wtc_with_http_info(x_version, x_token, content_type, tc_id, generate_wtc_body)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <GenerateWTCStatusResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->generate_wtc_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **content_type** | **String** | The Content Type of the body. Must be set to application/json. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |
| **generate_wtc_body** | [**GenerateWTCBody**](GenerateWTCBody.md) |  |  |

### Return type

[**GenerateWTCStatusResponse**](GenerateWTCStatusResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## get_cloud_archive_status

> <CloudArchiveGenerationResponse> get_cloud_archive_status(x_version, x_token, tc_id, generation_id)

Status - Generate Cloud Archive

Retrieves information status about a particular scheduled cloud archive generation.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetCollectionApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.
generation_id = 'generation_id_example' # String | Unique identifier of the asynchronous job created by a generation endpoint.

begin
  # Status - Generate Cloud Archive
  result = api_instance.get_cloud_archive_status(x_version, x_token, tc_id, generation_id)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->get_cloud_archive_status: #{e}"
end
```

#### Using the get_cloud_archive_status_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<CloudArchiveGenerationResponse>, Integer, Hash)> get_cloud_archive_status_with_http_info(x_version, x_token, tc_id, generation_id)

```ruby
begin
  # Status - Generate Cloud Archive
  data, status_code, headers = api_instance.get_cloud_archive_status_with_http_info(x_version, x_token, tc_id, generation_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <CloudArchiveGenerationResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->get_cloud_archive_status_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |
| **generation_id** | **String** | Unique identifier of the asynchronous job created by a generation endpoint. |  |

### Return type

[**CloudArchiveGenerationResponse**](CloudArchiveGenerationResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_image_target_collection

> <ImageTargetCollectionResponse> get_image_target_collection(x_version, x_token, tc_id)

Get Image Target Collection

Request a particular target collection from your account.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetCollectionApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.

begin
  # Get Image Target Collection
  result = api_instance.get_image_target_collection(x_version, x_token, tc_id)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->get_image_target_collection: #{e}"
end
```

#### Using the get_image_target_collection_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ImageTargetCollectionResponse>, Integer, Hash)> get_image_target_collection_with_http_info(x_version, x_token, tc_id)

```ruby
begin
  # Get Image Target Collection
  data, status_code, headers = api_instance.get_image_target_collection_with_http_info(x_version, x_token, tc_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ImageTargetCollectionResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->get_image_target_collection_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |

### Return type

[**ImageTargetCollectionResponse**](ImageTargetCollectionResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_image_target_collections

> <Array<ImageTargetCollectionResponse>> get_image_target_collections(x_version, x_token, opts)

Get all Image Target Collections

Request all target collections from your account.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetCollectionApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
opts = {
  skip: 56, # Integer | Set 0 to start with first entry, set e.g. to 2 to skip first 2 entries. Default value: 0
  limit: 56 # Integer | Use positive value to define the amount of entries to return [1, 1000] per page. Default value: 1000
}

begin
  # Get all Image Target Collections
  result = api_instance.get_image_target_collections(x_version, x_token, opts)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->get_image_target_collections: #{e}"
end
```

#### Using the get_image_target_collections_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<ImageTargetCollectionResponse>>, Integer, Hash)> get_image_target_collections_with_http_info(x_version, x_token, opts)

```ruby
begin
  # Get all Image Target Collections
  data, status_code, headers = api_instance.get_image_target_collections_with_http_info(x_version, x_token, opts)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<ImageTargetCollectionResponse>>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->get_image_target_collections_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **skip** | **Integer** | Set 0 to start with first entry, set e.g. to 2 to skip first 2 entries. Default value: 0 | [optional] |
| **limit** | **Integer** | Use positive value to define the amount of entries to return [1, 1000] per page. Default value: 1000 | [optional] |

### Return type

[**Array&lt;ImageTargetCollectionResponse&gt;**](ImageTargetCollectionResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_similarity_check_status

> <SimilarityCheckStatusResponse> get_similarity_check_status(x_version, x_token, tc_id, generation_id)

Status - Similarity Check

Retrieves information status of a particular scheduled \"Similarity Check\".

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetCollectionApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.
generation_id = 'generation_id_example' # String | Unique identifier of the asynchronous job created by a generation endpoint.

begin
  # Status - Similarity Check
  result = api_instance.get_similarity_check_status(x_version, x_token, tc_id, generation_id)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->get_similarity_check_status: #{e}"
end
```

#### Using the get_similarity_check_status_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<SimilarityCheckStatusResponse>, Integer, Hash)> get_similarity_check_status_with_http_info(x_version, x_token, tc_id, generation_id)

```ruby
begin
  # Status - Similarity Check
  data, status_code, headers = api_instance.get_similarity_check_status_with_http_info(x_version, x_token, tc_id, generation_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <SimilarityCheckStatusResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->get_similarity_check_status_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |
| **generation_id** | **String** | Unique identifier of the asynchronous job created by a generation endpoint. |  |

### Return type

[**SimilarityCheckStatusResponse**](SimilarityCheckStatusResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_wtc_status

> <GenerateWTCStatusResponse> get_wtc_status(x_version, x_token, tc_id, generation_id)

Status - Generate WTC

Retrieves information status about a particular scheduled WTC file generation. Once the status is completed, the WTC information can be retrieved from the Target Collection (see Get Target Collection). 

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetCollectionApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.
generation_id = 'generation_id_example' # String | Unique identifier of the asynchronous job created by a generation endpoint.

begin
  # Status - Generate WTC
  result = api_instance.get_wtc_status(x_version, x_token, tc_id, generation_id)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->get_wtc_status: #{e}"
end
```

#### Using the get_wtc_status_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<GenerateWTCStatusResponse>, Integer, Hash)> get_wtc_status_with_http_info(x_version, x_token, tc_id, generation_id)

```ruby
begin
  # Status - Generate WTC
  data, status_code, headers = api_instance.get_wtc_status_with_http_info(x_version, x_token, tc_id, generation_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <GenerateWTCStatusResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->get_wtc_status_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |
| **generation_id** | **String** | Unique identifier of the asynchronous job created by a generation endpoint. |  |

### Return type

[**GenerateWTCStatusResponse**](GenerateWTCStatusResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## similarity_check

> <SimilarityCheckResponse> similarity_check(x_version, x_token, content_type, tc_id, similarity_check_body)

Similarity Check

Pass up to 10 items pointing to PNG or JPEG images hosted via https in the body. In order to find out whether an image is similar to an existing Target in terms of recognition and tracking behaviour a check is performed per passed image item. The Target Collection must be published and have an active Cloud Archive in place. Up to 5 (default: 1) so called \"candidates\" with a similarity \"score\" are returned per image. Image must be hosted via https and be of type PNG or JPEG. Use \"maxCandidates\" to define the maximum amount of candidates to return for an image. Response header value \"Location\" directly points to the right \"Status - Similarity Check\" endpoint. Best practice is to trigger \"Similarity Check\", wait for \"estimatedLatency\" milliseconds and poll \"Status - Similarity Check\" endpoint every 5 seconds until its \"status\" is \"COMPLETED\". 

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetCollectionApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
content_type = 'content_type_example' # String | The Content Type of the body. Must be set to application/json.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.
similarity_check_body = WikitudeStudioAPIClient::SimilarityCheckBody.new # SimilarityCheckBody | 

begin
  # Similarity Check
  result = api_instance.similarity_check(x_version, x_token, content_type, tc_id, similarity_check_body)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->similarity_check: #{e}"
end
```

#### Using the similarity_check_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<SimilarityCheckResponse>, Integer, Hash)> similarity_check_with_http_info(x_version, x_token, content_type, tc_id, similarity_check_body)

```ruby
begin
  # Similarity Check
  data, status_code, headers = api_instance.similarity_check_with_http_info(x_version, x_token, content_type, tc_id, similarity_check_body)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <SimilarityCheckResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->similarity_check_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **content_type** | **String** | The Content Type of the body. Must be set to application/json. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |
| **similarity_check_body** | [**SimilarityCheckBody**](SimilarityCheckBody.md) |  |  |

### Return type

[**SimilarityCheckResponse**](SimilarityCheckResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## update_image_target_collection

> <ImageTargetCollectionResponse> update_image_target_collection(x_version, x_token, content_type, tc_id, update_image_target_collection_body)

Update Image Target Collection

Update a target collection from your account.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ImageTargetCollectionApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
content_type = 'content_type_example' # String | The Content Type of the body. Must be set to application/json.
tc_id = 'tc_id_example' # String | Unique identifier of the Image Target Collection.
update_image_target_collection_body = WikitudeStudioAPIClient::UpdateImageTargetCollectionBody.new # UpdateImageTargetCollectionBody | 

begin
  # Update Image Target Collection
  result = api_instance.update_image_target_collection(x_version, x_token, content_type, tc_id, update_image_target_collection_body)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->update_image_target_collection: #{e}"
end
```

#### Using the update_image_target_collection_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ImageTargetCollectionResponse>, Integer, Hash)> update_image_target_collection_with_http_info(x_version, x_token, content_type, tc_id, update_image_target_collection_body)

```ruby
begin
  # Update Image Target Collection
  data, status_code, headers = api_instance.update_image_target_collection_with_http_info(x_version, x_token, content_type, tc_id, update_image_target_collection_body)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ImageTargetCollectionResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ImageTargetCollectionApi->update_image_target_collection_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **content_type** | **String** | The Content Type of the body. Must be set to application/json. |  |
| **tc_id** | **String** | Unique identifier of the Image Target Collection. |  |
| **update_image_target_collection_body** | [**UpdateImageTargetCollectionBody**](UpdateImageTargetCollectionBody.md) |  |  |

### Return type

[**ImageTargetCollectionResponse**](ImageTargetCollectionResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

