# WikitudeStudioAPIClient::ObjectTargetApi

All URIs are relative to *https://api-eu.wikitude.com/cloudrecognition*

| Method | HTTP request | Description |
| ------ | ------------ | ----------- |
| [**create_object_target_from_images**](ObjectTargetApi.md#create_object_target_from_images) | **POST** /objectTargetCollection/{tcId}/target/images | Create Object Target from Images |
| [**create_object_target_from_wto**](ObjectTargetApi.md#create_object_target_from_wto) | **POST** /objectTargetCollection/{tcId}/target/wto | Create Object Target from WTO |
| [**delete_object_target**](ObjectTargetApi.md#delete_object_target) | **DELETE** /objectTargetCollection/{tcId}/target/{targetId} | Delete Object Target |
| [**extend_object_target**](ObjectTargetApi.md#extend_object_target) | **PUT** /objectTargetCollection/{tcId}/target/{targetId} | Extend Object Target |
| [**get_object_target**](ObjectTargetApi.md#get_object_target) | **GET** /objectTargetCollection/{tcId}/target/{targetId} | Get Object Target |
| [**get_object_target_status**](ObjectTargetApi.md#get_object_target_status) | **GET** /objectTargetCollection/{tcId}/generation/targets/{generationId} | Status - Object Target Generation Information |
| [**get_object_targets**](ObjectTargetApi.md#get_object_targets) | **GET** /objectTargetCollection/{tcId}/target | Get Object Targets |
| [**rename_object_target**](ObjectTargetApi.md#rename_object_target) | **PUT** /objectTargetCollection/{tcId}/target/{targetId}/name | Rename Object Target |


## create_object_target_from_images

> <ObjectTargetJobResponse> create_object_target_from_images(x_version, x_token, content_type, tc_id, create_object_target_images_body)

Create Object Target from Images

Create a new Object Target in an Object Target Collection from at least two Image files.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ObjectTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
content_type = 'content_type_example' # String | The Content Type of the body. Must be set to application/json.
tc_id = 'tc_id_example' # String | Unique identifier of the Object Target Collection.
create_object_target_images_body = WikitudeStudioAPIClient::CreateObjectTargetImagesBody.new # CreateObjectTargetImagesBody | 

begin
  # Create Object Target from Images
  result = api_instance.create_object_target_from_images(x_version, x_token, content_type, tc_id, create_object_target_images_body)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->create_object_target_from_images: #{e}"
end
```

#### Using the create_object_target_from_images_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ObjectTargetJobResponse>, Integer, Hash)> create_object_target_from_images_with_http_info(x_version, x_token, content_type, tc_id, create_object_target_images_body)

```ruby
begin
  # Create Object Target from Images
  data, status_code, headers = api_instance.create_object_target_from_images_with_http_info(x_version, x_token, content_type, tc_id, create_object_target_images_body)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ObjectTargetJobResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->create_object_target_from_images_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **content_type** | **String** | The Content Type of the body. Must be set to application/json. |  |
| **tc_id** | **String** | Unique identifier of the Object Target Collection. |  |
| **create_object_target_images_body** | [**CreateObjectTargetImagesBody**](CreateObjectTargetImagesBody.md) |  |  |

### Return type

[**ObjectTargetJobResponse**](ObjectTargetJobResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## create_object_target_from_wto

> <ObjectTargetJobResponse> create_object_target_from_wto(x_version, x_token, content_type, tc_id, create_object_target_wto_body)

Create Object Target from WTO

Create a new Object Target in an Object Target Collection from a WTO file.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ObjectTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
content_type = 'content_type_example' # String | The Content Type of the body. Must be set to application/json.
tc_id = 'tc_id_example' # String | Unique identifier of the Object Target Collection.
create_object_target_wto_body = WikitudeStudioAPIClient::CreateObjectTargetWTOBody.new # CreateObjectTargetWTOBody | 

begin
  # Create Object Target from WTO
  result = api_instance.create_object_target_from_wto(x_version, x_token, content_type, tc_id, create_object_target_wto_body)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->create_object_target_from_wto: #{e}"
end
```

#### Using the create_object_target_from_wto_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ObjectTargetJobResponse>, Integer, Hash)> create_object_target_from_wto_with_http_info(x_version, x_token, content_type, tc_id, create_object_target_wto_body)

```ruby
begin
  # Create Object Target from WTO
  data, status_code, headers = api_instance.create_object_target_from_wto_with_http_info(x_version, x_token, content_type, tc_id, create_object_target_wto_body)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ObjectTargetJobResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->create_object_target_from_wto_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **content_type** | **String** | The Content Type of the body. Must be set to application/json. |  |
| **tc_id** | **String** | Unique identifier of the Object Target Collection. |  |
| **create_object_target_wto_body** | [**CreateObjectTargetWTOBody**](CreateObjectTargetWTOBody.md) |  |  |

### Return type

[**ObjectTargetJobResponse**](ObjectTargetJobResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## delete_object_target

> delete_object_target(x_version, x_token, tc_id, target_id)

Delete Object Target

Delete a particular Object Target from your Object Target Collection.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ObjectTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Object Target Collection.
target_id = 'target_id_example' # String | Unique identifier of the Object Target.

begin
  # Delete Object Target
  api_instance.delete_object_target(x_version, x_token, tc_id, target_id)
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->delete_object_target: #{e}"
end
```

#### Using the delete_object_target_with_http_info variant

This returns an Array which contains the response data (`nil` in this case), status code and headers.

> <Array(nil, Integer, Hash)> delete_object_target_with_http_info(x_version, x_token, tc_id, target_id)

```ruby
begin
  # Delete Object Target
  data, status_code, headers = api_instance.delete_object_target_with_http_info(x_version, x_token, tc_id, target_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => nil
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->delete_object_target_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Object Target Collection. |  |
| **target_id** | **String** | Unique identifier of the Object Target. |  |

### Return type

nil (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## extend_object_target

> <ObjectTargetJobResponse> extend_object_target(x_version, x_token, content_type, tc_id, target_id, extend_object_target_body)

Extend Object Target

Add source images to an existing target.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ObjectTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
content_type = 'content_type_example' # String | The Content Type of the body. Must be set to application/json.
tc_id = 'tc_id_example' # String | Unique identifier of the Object Target Collection.
target_id = 'target_id_example' # String | Unique identifier of the Object Target.
extend_object_target_body = WikitudeStudioAPIClient::ExtendObjectTargetBody.new # ExtendObjectTargetBody | 

begin
  # Extend Object Target
  result = api_instance.extend_object_target(x_version, x_token, content_type, tc_id, target_id, extend_object_target_body)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->extend_object_target: #{e}"
end
```

#### Using the extend_object_target_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ObjectTargetJobResponse>, Integer, Hash)> extend_object_target_with_http_info(x_version, x_token, content_type, tc_id, target_id, extend_object_target_body)

```ruby
begin
  # Extend Object Target
  data, status_code, headers = api_instance.extend_object_target_with_http_info(x_version, x_token, content_type, tc_id, target_id, extend_object_target_body)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ObjectTargetJobResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->extend_object_target_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **content_type** | **String** | The Content Type of the body. Must be set to application/json. |  |
| **tc_id** | **String** | Unique identifier of the Object Target Collection. |  |
| **target_id** | **String** | Unique identifier of the Object Target. |  |
| **extend_object_target_body** | [**ExtendObjectTargetBody**](ExtendObjectTargetBody.md) |  |  |

### Return type

[**ObjectTargetJobResponse**](ObjectTargetJobResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## get_object_target

> <ObjectTargetResponse> get_object_target(x_version, x_token, tc_id, target_id)

Get Object Target

Request a specific Object Targets from your account.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ObjectTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Object Target Collection.
target_id = 'target_id_example' # String | Unique identifier of the Object Target.

begin
  # Get Object Target
  result = api_instance.get_object_target(x_version, x_token, tc_id, target_id)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->get_object_target: #{e}"
end
```

#### Using the get_object_target_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ObjectTargetResponse>, Integer, Hash)> get_object_target_with_http_info(x_version, x_token, tc_id, target_id)

```ruby
begin
  # Get Object Target
  data, status_code, headers = api_instance.get_object_target_with_http_info(x_version, x_token, tc_id, target_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ObjectTargetResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->get_object_target_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Object Target Collection. |  |
| **target_id** | **String** | Unique identifier of the Object Target. |  |

### Return type

[**ObjectTargetResponse**](ObjectTargetResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_object_target_status

> <ObjectTargetJobResponse> get_object_target_status(x_version, x_token, tc_id, generation_id)

Status - Object Target Generation Information

Retrieves information status about a particular scheduled Object Target creation.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ObjectTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Object Target Collection.
generation_id = 'generation_id_example' # String | Unique identifier of the asynchronous job created by a generation endpoint.

begin
  # Status - Object Target Generation Information
  result = api_instance.get_object_target_status(x_version, x_token, tc_id, generation_id)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->get_object_target_status: #{e}"
end
```

#### Using the get_object_target_status_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ObjectTargetJobResponse>, Integer, Hash)> get_object_target_status_with_http_info(x_version, x_token, tc_id, generation_id)

```ruby
begin
  # Status - Object Target Generation Information
  data, status_code, headers = api_instance.get_object_target_status_with_http_info(x_version, x_token, tc_id, generation_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ObjectTargetJobResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->get_object_target_status_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Object Target Collection. |  |
| **generation_id** | **String** | Unique identifier of the asynchronous job created by a generation endpoint. |  |

### Return type

[**ObjectTargetJobResponse**](ObjectTargetJobResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## get_object_targets

> <Array<ObjectTargetResponse>> get_object_targets(x_version, x_token, tc_id)

Get Object Targets

Request all Object Targets in a Target Collection.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ObjectTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
tc_id = 'tc_id_example' # String | Unique identifier of the Object Target Collection.

begin
  # Get Object Targets
  result = api_instance.get_object_targets(x_version, x_token, tc_id)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->get_object_targets: #{e}"
end
```

#### Using the get_object_targets_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<Array<ObjectTargetResponse>>, Integer, Hash)> get_object_targets_with_http_info(x_version, x_token, tc_id)

```ruby
begin
  # Get Object Targets
  data, status_code, headers = api_instance.get_object_targets_with_http_info(x_version, x_token, tc_id)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <Array<ObjectTargetResponse>>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->get_object_targets_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **tc_id** | **String** | Unique identifier of the Object Target Collection. |  |

### Return type

[**Array&lt;ObjectTargetResponse&gt;**](ObjectTargetResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## rename_object_target

> <ObjectTargetJobResponse> rename_object_target(x_version, x_token, content_type, tc_id, target_id, rename_object_target_body)

Rename Object Target

Rename an existing target.

### Examples

```ruby
require 'time'
require 'wikitude_studio_api_client'

api_instance = WikitudeStudioAPIClient::ObjectTargetApi.new
x_version = '3' # String | The version of the API to be used. Must be set to 3.
x_token = 'x_token_example' # String | Your Manager Token.
content_type = 'content_type_example' # String | The Content Type of the body. Must be set to application/json.
tc_id = 'tc_id_example' # String | Unique identifier of the Object Target Collection.
target_id = 'target_id_example' # String | Unique identifier of the Object Target.
rename_object_target_body = WikitudeStudioAPIClient::RenameObjectTargetBody.new # RenameObjectTargetBody | 

begin
  # Rename Object Target
  result = api_instance.rename_object_target(x_version, x_token, content_type, tc_id, target_id, rename_object_target_body)
  p result
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->rename_object_target: #{e}"
end
```

#### Using the rename_object_target_with_http_info variant

This returns an Array which contains the response data, status code and headers.

> <Array(<ObjectTargetJobResponse>, Integer, Hash)> rename_object_target_with_http_info(x_version, x_token, content_type, tc_id, target_id, rename_object_target_body)

```ruby
begin
  # Rename Object Target
  data, status_code, headers = api_instance.rename_object_target_with_http_info(x_version, x_token, content_type, tc_id, target_id, rename_object_target_body)
  p status_code # => 2xx
  p headers # => { ... }
  p data # => <ObjectTargetJobResponse>
rescue WikitudeStudioAPIClient::ApiError => e
  puts "Error when calling ObjectTargetApi->rename_object_target_with_http_info: #{e}"
end
```

### Parameters

| Name | Type | Description | Notes |
| ---- | ---- | ----------- | ----- |
| **x_version** | **String** | The version of the API to be used. Must be set to 3. |  |
| **x_token** | **String** | Your Manager Token. |  |
| **content_type** | **String** | The Content Type of the body. Must be set to application/json. |  |
| **tc_id** | **String** | Unique identifier of the Object Target Collection. |  |
| **target_id** | **String** | Unique identifier of the Object Target. |  |
| **rename_object_target_body** | [**RenameObjectTargetBody**](RenameObjectTargetBody.md) |  |  |

### Return type

[**ObjectTargetJobResponse**](ObjectTargetJobResponse.md)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

